Database connection and session management
This module provides the main entry points for working with GraphLite databases. It follows a similar pattern to rusqlite (SQLite’s Rust bindings) but adapted for graph databases.
Database connection and session management
This module provides the main entry points for working with GraphLite databases. It follows a similar pattern to rusqlite (SQLite’s Rust bindings) but adapted for graph databases.